@@ -3,6 +3,10 @@ from django.urls import reverse
 
 from mentions.views import view_names
 
+__all__ = [
+    "WebmentionHeadMiddleware",
+]
+
 
 class WebmentionHeadMiddleware:
     """Automatically add webmention endpoint to HTTP headers of any HttpResponse
@@ -13,10 +17,8 @@ class WebmentionHeadMiddleware:
 
     def __call__(self, request):
         response = self.get_response(request)
-        port = request.META.get("SERVER_PORT", 80)
         path = reverse(view_names.webmention_api_incoming)
-        response["Link"] = (
-            f"<{request.scheme}://{settings.DOMAIN_NAME}:{port}{path}>"
-            ';rel="webmention"'
-        )
+        response[
+            "Link"
+        ] = f'<{request.scheme}://{settings.DOMAIN_NAME}{path}>; rel="webmention"'
         return response
