@@ -1,23 +1,19 @@
-import logging
 from typing import List, Type
 
-from django.contrib.contenttypes.models import ContentType
 from django.db import models
 
 from mentions.exceptions import ImplementationRequired
-from mentions.models import QuotableMixin, SimpleMention
-from mentions.models.webmention import Webmention
-from mentions.serialize import serialize_mentions
-from mentions.tasks.scheduling import handle_outgoing_webmentions
+from mentions.models.mixins.quotable import QuotableMixin
 
-log = logging.getLogger(__name__)
+__all__ = [
+    "MentionableMixin",
+]
 
 
 class MentionableMixin(models.Model):
     class Meta:
         abstract = True
 
-    allow_incoming_webmentions = models.BooleanField(default=True)
     allow_outgoing_webmentions = models.BooleanField(default=False)
 
     # `slug` field is no longer required as of version 2.3.0.
@@ -25,23 +21,15 @@ class MentionableMixin(models.Model):
     # a default implementation of :func:`resolve_from_url_kwargs`
     slug = models.SlugField(unique=True)
 
-    @property
-    def mentions(self) -> List[QuotableMixin]:
-        ctype = ContentType.objects.get_for_model(self.__class__)
-        webmentions = Webmention.objects.filter(
-            content_type=ctype,
-            object_id=self.id,
-            approved=True,
-            validated=True,
-        )
-        simple_mentions = SimpleMention.objects.filter(
-            content_type=ctype,
-            object_id=self.id,
-        )
-        return list(webmentions) + list(simple_mentions)
+    def mentions(self) -> List["QuotableMixin"]:
+        from mentions.resolution import get_mentions_for_object
+
+        return get_mentions_for_object(self)
 
     def mentions_json(self):
-        return serialize_mentions(self.mentions)
+        from mentions.serialize import serialize_mentions
+
+        return serialize_mentions(self.mentions())
 
     def get_absolute_url(self):
         raise ImplementationRequired(
@@ -86,8 +74,14 @@ class MentionableMixin(models.Model):
         """
         return cls.objects.get(slug=url_kwargs.get("slug"))
 
-    def save(self, *args, **kwargs):
-        if self.allow_outgoing_webmentions:
-            handle_outgoing_webmentions(self.get_absolute_url(), self.all_text())
+    def should_process_webmentions(self) -> bool:
+        """Return True if this instance should process webmentions when saved."""
+        return self.allow_outgoing_webmentions
 
+    def save(self, *args, **kwargs):
         super().save(*args, **kwargs)
+
+        if self.should_process_webmentions():
+            from mentions.tasks import handle_outgoing_webmentions
+
+            handle_outgoing_webmentions(self.get_absolute_url(), self.all_text())
