@@ -1,9 +1,16 @@
 from django.db import models
+from django.db.models import UniqueConstraint
 
-from mentions.models import MentionsBaseModel
+from mentions.models.base import MentionsBaseModel
+from mentions.models.mixins import RetryableMixin
+
+__all__ = [
+    "PendingIncomingWebmention",
+    "PendingOutgoingContent",
+]
 
 
-class PendingIncomingWebmention(MentionsBaseModel):
+class PendingIncomingWebmention(RetryableMixin, MentionsBaseModel):
     """Temporary store of data about an incoming webmention.
 
     Only used if settings.WEBMENTIONS_USE_CELERY is False.
@@ -22,6 +29,12 @@ class PendingIncomingWebmention(MentionsBaseModel):
 
     class Meta:
         ordering = ["-created_at"]
+        constraints = [
+            UniqueConstraint(
+                fields=("source_url", "target_url"),
+                name="unique_source_url_per_target_url",
+            ),
+        ]
 
 
 class PendingOutgoingContent(MentionsBaseModel):
@@ -30,7 +43,8 @@ class PendingOutgoingContent(MentionsBaseModel):
     Use `manage.py pending_mentions` to process."""
 
     absolute_url = models.URLField(
-        help_text="URL on our server where the content can be found."
+        help_text="URL on our server where the content can be found.",
+        unique=True,
     )
     text = models.TextField(
         help_text="Text that may contain mentionable links. (retrieved via MentionableMixin.all_text())"
